#!/bin/bash
if [ ! $# == 2 ]; then
  echo "Usage: $0 sub_theme_name [zurb | zurb6 | bootstrap | clean]"
  exit
fi

#Check if folder exists
if [ -d ../../custom/$1 ]
then
	echo "the $1 folder already exists"
	exit 1
fi

if [ $2 != 'zurb' ] && [ $2 != 'zurb6' ] && [ $2 != 'bootstrap' ] && [ $2 != 'clean' ]
then
	echo "You need to provide the framework you want to use zurb, zurb6, bootstrap or clean"
	exit 1;
fi

if [ $2 != 'zurb' ] && [ $2 != 'bootstrap' ]
then
type composer >/dev/null 2>&1 || { echo >&2 "I require composer but it's not installed.  Aborting."; exit 1; }
fi

#create folder for subtheme
mkdir ../../custom/$1

#Copy basic files and folders
cp *png ../../custom/$1
cp *.rb ../../custom/$1
cp *.txt ../../custom/$1
mkdir ../../custom/$1/templates
cp templates/block--whitecanvas-account-menu.html.twig ../../custom/$1/templates/block--$1-account-menu.html.twig
cp templates/block--whitecanvas-main-menu.html.twig ../../custom/$1/templates/block--$1-main-menu.html.twig

mkdir ../../custom/$1/css
mkdir ../../custom/$1/config
mkdir ../../custom/$1/config/install
mkdir ../../custom/$1/config/schema


#copy starterkit files
cp starterkit/starterkit.info.yml.example ../../custom/$1/$1.info.yml
cp starterkit/starterkit.theme.example ../../custom/$1/$1.theme
cp starterkit/starterkit.libraries.yml ../../custom/$1/$1.libraries.yml
cp starterkit/starterkit.schema.yml ../../custom/$1/config/schema/$1.schema.yml
cp starterkit/starterkit.breakpoints.yml ../../custom/$1/config/install/$1.breakpoints.yml

#specific framework tasks
	mkdir ../../custom/$1/scss
	cp -rf ../whitecanvas/scss/base ../../custom/$1/scss
	cp -rf ../whitecanvas/scss/components ../../custom/$1/scss
	cp -rf ../whitecanvas/scss/layout ../../custom/$1/scss
	cp -rf ../whitecanvas/scss/states ../../custom/$1/scss
	cp -rf ../whitecanvas/scss/theme ../../custom/$1/scss

#foundation
if [ $2 == 'zurb' ]
then
        cp composer-foundation.json ../../custom/$1/composer-framework.json
        cp -rf scss/foundation ../../custom/$1/scss
        cp scss/whitecanvas-foundation.scss ../../custom/$1/scss/$1-foundation.scss
        cp -rf js ../../custom/$1
        cp starterkit/starterkit.foundation.settings.yml.example ../../custom/$1/$1.settings.yml
fi

#bootstrap
if [ $2 == 'bootstrap' ]
then
	cp -rf scss/*bootstrap* ../../custom/$1/scss
	mkdir ../../custom/$1/js
	cp starterkit/starterkit.bootstrap.settings.yml.example ../../custom/$1/$1.settings.yml
fi


cd ../../custom/$1

if [ $2 != 'zurb' ] && [ $2 != 'bootstrap' ]
then
    composer install
else
    bower install
fi

#final Touch
cd ../../custom/$1

find . -type f -exec sed -i "s/starterkit/$1/g" {} +
