<?php
/**
 * @file
 * Theme setting's form override.
 */

use Symfony\Component\Validator\Constraints\True;

/**
 * Cretes the form for the theme settings.
 *
 * @param array $form
 *   The form Array.
 * @param array $form_state
 *   The current form state.
 */
function whitecanvas_form_system_theme_settings_alter(&$form, $form_state) {
  // Group of settings.
  $form['whitecanvas_settings'] = array(
    '#type' => 'vertical_tabs',
    '#title' => t('Theme Specific Settings'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );

  // General Settings.
  $form['whitecanvas_general'] = array(
    '#type' => 'details',
    '#title' => t('General Settings'),
    '#group' => 'whitecanvas_settings',
  );

  $form['whitecanvas_general']['theme_settings'] = $form['theme_settings'];
  unset($form['theme_settings']);

  $form['whitecanvas_general']['logo'] = $form['logo'];
  unset($form['logo']);

  $form['whitecanvas_general']['favicon'] = $form['favicon'];
  unset($form['favicon']);

  // Select framework.
  $form['whitecanvas_options'] = array(
    '#type' => 'details',
    '#title' => t('Theme Options'),
    '#group' => 'whitecanvas_settings',
  );

  $form['whitecanvas_options']['whitecanvas_framework'] = array(
    '#type' => 'select',
    '#title' => t('Select your framework'),
    '#description' => t('Select the CSS Framework that you want to use to activate particular features'),
    '#options' => array(
      'foundation' => t('Zurb Foundation 5'),
      'foundation6' => t('Zurb Foundation 6'),
      'bootstrap' => t('Bootstrap 3'),
      'clean' => t('No Framework'),
    ),
    '#default_value' => theme_get_setting('whitecanvas_framework'),
  );

  // Should we reset other settings for other frameworks?
  // Beginning of Zurb Foundation 5.
  // Zurb Foundation 5 settings fieldset.
  $form['whitecanvas_options']['zurb_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Zurb Foundation Options'),
    '#states' => array(
      'visible' => array(
        'select[name="whitecanvas_framework"]' => array('value' => 'foundation'),
      ),
    ),
  );

  // ZURB FOUNDATION 5 SPECIFIC.
  // Topbar.
  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_use_navbar'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Top Bar'),
    '#description' => t('Check if you want the theme to use the Top Bar'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_use_navbar'),
  );
  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Top Bar Options'),
    '#states' => array(
      'invisible' => array(

        ':input[name="whitecanvas_zurb_use_navbar"]' => array('checked' => FALSE),
      ),
    ),
  );
  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_navbar_site_name'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Site Name in NavBar'),
    '#description' => t('Check this for your top bar to display the site name.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_navbar_site_name'),
  );
  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_topbar_fixed'] = array(
    '#type' => 'checkbox',
    '#title' => t('Fixed to Top'),
    '#description' => t('Check this for your top bar to be fixed to the top.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_topbar_fixed'),
  );
  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_topbar_grid'] = array(
    '#type' => 'checkbox',
    '#title' => t('Contain to grid'),
    '#description' => t('Check this for your top bar to be set to your grid width.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_topbar_grid'),
  );
  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_topbar_sticky'] = array(
    '#type' => 'checkbox',
    '#title' => t('Sticky'),
    '#description' => t('Check this for your top bar to be sticky.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_topbar_sticky'),
  );
  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_topbar_sticky']['sticky_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Sticky Options'),
    /*    '#states' => array(
        'visible' => array(

    ':input[name="whitecanvas_zurb_topbar_sticky"]' => array('checked' => TRUE),
        ),
      ),*/
  );
  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_topbar_sticky']['sticky_options']['whitecanvas_zurb_sticky_large'] = array(
    '#type' => 'checkbox',
    '#title' => t('Sticky on Large'),
    '#description' => t('Check this for your top bar to be sticky on large screens.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_sticky_large'),
  );

  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_topbar_sticky']['sticky_options']['whitecanvas_zurb_sticky_medium'] = array(
    '#type' => 'checkbox',
    '#title' => t('Sticky on Medium'),
    '#description' => t('Check this for your top bar to be sticky on medium screens.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_sticky_medium'),
  );

  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_topbar_sticky']['sticky_options']['whitecanvas_zurb_sticky_small'] = array(
    '#type' => 'checkbox',
    '#title' => t('Sticky on Small'),
    '#description' => t('Check this for your top bar to be sticky on small screens.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_sticky_small'),
  );

  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_topbar_top'] = array(
    '#type' => 'checkbox',
    '#title' => t('Back to Top'),
    '#description' => t('Check this for your top bar to scroll back to top when clicked.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_topbar_top'),
  );
  $form['whitecanvas_options']['zurb_options']['whitecanvas_zurb_topbar_options']['whitecanvas_zurb_topbar_hover'] = array(
    '#type' => 'checkbox',
    '#title' => t('Click, not hover, to expand menu'),
    '#description' => t('Check this to require the user to click to expand the dropdown menu.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb_topbar_hover'),
  );

  // End of Zurb Foundatioon 5.

  // Beginning of Zurb Foundation 6.
  // Zurb Foundation 5 settings fieldset.
  $form['whitecanvas_options']['zurb6_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Zurb Foundation 6 Options'),
    '#states' => array(
      'visible' => array(
        'select[name="whitecanvas_framework"]' => array('value' => 'foundation6'),
      ),
    ),
  );

  // ZURB FOUNDATION 6 SPECIFIC.
  // Topbar.
  $form['whitecanvas_options']['zurb6_options']['whitecanvas_zurb6_use_navbar'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Foundation 6 Top Bar'),
    '#description' => t('Check if you want the theme to use the Top Bar'),
    '#default_value' => theme_get_setting('whitecanvas_zurb6_use_navbar'),
  );
  $form['whitecanvas_options']['zurb6_options']['whitecanvas_zurb6_topbar_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Foundation 6 Top Bar Options'),
    '#states' => array(
      'invisible' => array(

        ':input[name="whitecanvas_zurb6_use_navbar"]' => array('checked' => FALSE),
      ),
    ),
  );
  $form['whitecanvas_options']['zurb6_options']['whitecanvas_zurb6_topbar_options']['whitecanvas_zurb6_navbar_site_name'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Site Name in Foundation 6 TopBar'),
    '#description' => t('Check this for your top bar to display the site name.'),
    '#default_value' => theme_get_setting('whitecanvas_zurb6_navbar_site_name'),
  );

  // End of Zurb Foundatioon 6.

  // Twitter Bootstrap Settings Fieldset.
  $form['whitecanvas_options']['bootstrap_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Twitter Bootstrap Options'),
    '#states' => array(
      'visible' => array(
        'select[name="whitecanvas_framework"]' => array('value' => 'bootstrap'),
      ),
    ),
  );

  // TWITTER BOOTSTRAP SPECIFIC.
  // Nav Bar.
  $form['whitecanvas_options']['bootstrap_options']['whitecanvas_bootstrap_use_navbar'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Nav Bar'),
    '#description' => t('Check if you want the theme to use the Nav Bar'),
    '#default_value' => theme_get_setting('whitecanvas_bootstrap_use_navbar'),
  );
  $form['whitecanvas_options']['bootstrap_options']['whitecanvas_bootstrap_nav_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Top Bar Options'),
    '#states' => array(
      'invisible' => array(

        ':input[name="whitecanvas_bootstrap_use_navbar"]' => array('checked' => FALSE),
      ),
    ),
  );
  $form['whitecanvas_options']['bootstrap_options']['whitecanvas_bootstrap_nav_options']['whitecanvas_bootstrap_navbar_site_name'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Site Name in NavBar'),
    '#description' => t('Check this for your top bar to display the site name.'),
    '#default_value' => theme_get_setting('whitecanvas_bootstrap_navbar_site_name'),
  );
  //End of Bootstrap config

  // CLEAN SPECIFIC.
  $form['whitecanvas_options']['clean_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Clean (No framework) Options'),
    '#states' => array(
      'visible' => array(
        'select[name="whitecanvas_framework"]' => array('value' => 'clean'),
      ),
    ),
  );

  // Bare.
  $form['whitecanvas_options']['clean_options']['whitecanvas_clean_bare'] = array(
    '#type' => 'checkbox',
    '#title' => t('Bare of templates (Very Experimental and Dangerous)'),
    '#description' => t('Check if you want whitecanvas to not use any Classy template and create your templates from scratch'),
    '#default_value' => theme_get_setting('whitecanvas_clean_bare'),
  );
  //End of clean config
}
